@@ -1,7 +1,7 @@
 import sys
-from typing import Any, Iterable, Mapping, Sequence
+from typing import Any, Iterable, Mapping, Optional, Sequence, Union
 
-from pychoir.core import Matchable, Matcher
+from pychoir.core import Matchable, Matcher, Transformer
 
 if sys.version_info >= (3, 8):
     from typing import Protocol
@@ -266,3 +266,135 @@ class IsNotPresentOr(Matcher):
 
     def _description(self) -> str:
         return repr(self.matcher)
+
+
+class _First(Matcher):
+    def __init__(self, how_many: int, matcher: Matchable):
+        super().__init__(override_name='First')
+        self.how_many = how_many
+        self.matcher = matcher
+
+    def _matches(self, other: Sequence[Any]) -> bool:
+        if self.how_many < 2:
+            first = other[0]
+        else:
+            first = other[:self.how_many]
+        return self.nested_match(self.matcher, first)
+
+    def _description(self) -> str:
+        matcher_string = repr(self.matcher)
+        return f'{self.how_many})({matcher_string}'
+
+
+class First(Transformer):
+    """A Higher Order Matcher checking that the first `how_many` values match given matchers.
+    The matcher is applied to the slice extracted from the passed :class:`Sequence`.
+
+    :param how_many: The number of values to slice from the start of the sequence being compared.
+
+    Usage:
+      >>> from pychoir import First, All, GreaterThan
+      >>> (1, 2, 3) == First(2)((1, 2))
+      True
+      >>> (1, 2, 3) == First()(1)
+      True
+    """
+    def __init__(self, how_many: int = 1):
+        super().__init__()
+        self.how_many = how_many
+        self.matcher: Optional[Matchable] = None
+
+    def __call__(self, matcher: Matchable) -> _First:
+        """
+        :param matcher: The :class:`Matcher` to apply on the extracted slice.
+        """
+        return _First(self.how_many, matcher)
+
+
+class _Last(Matcher):
+    def __init__(self, how_many: int, matcher: Matchable):
+        super().__init__(override_name='Last')
+        self.how_many = how_many
+        self.matcher = matcher
+
+    def _matches(self, other: Sequence[Any]) -> bool:
+        if self.how_many < 2:
+            last = other[-1]
+        else:
+            last = other[-self.how_many:]
+        return self.nested_match(self.matcher, last)
+
+    def _description(self) -> str:
+        matcher_string = repr(self.matcher)
+        return f'{self.how_many})({matcher_string}'
+
+
+class Last(Transformer):
+    """A Higher Order Matcher checking that the last `how_many` values match given matchers.
+    The matcher is applied to the slice extracted from the passed :class:`Sequence`.
+
+    :param how_many: The number of values to slice from the end of the sequence being compared.
+
+    Usage:
+      >>> from pychoir import Last, All, LessThan
+      >>> (1, 2, 3) == Last(2)((2, 3))
+      True
+      >>> (1, 2, 3) == Last()(3)
+      True
+    """
+    def __init__(self, how_many: int = 1):
+        self.how_many = how_many
+
+    def __call__(self, matcher: Matchable) -> _Last:
+        """
+        :param matcher: The :class:`Matcher` to apply on the extracted slice.
+        """
+        return _Last(self.how_many, matcher)
+
+
+class _Slice(Matcher):
+    def __init__(self, slice_: Union[int, slice], matcher: Matchable) -> None:
+        super().__init__(override_name=f'Slice[{slice_}]')
+        self.slice = slice_
+        self.matcher = matcher
+
+    def _matches(self, other: Any) -> bool:
+        sliced = other[self.slice]
+        return self.nested_match(self.matcher, sliced)
+
+    def _description(self) -> str:
+        return repr(self.matcher)
+
+
+class _SliceTransformer(Transformer):
+    """Extracts `slice_` from the matched value before checking it with a Matcher.
+    """
+    def __init__(self, slice_: Union[int, slice]) -> None:
+        self.slice: Union[int, slice] = slice_
+
+    def __call__(self, matcher: Matchable) -> _Slice:
+        """
+        :param matcher: The :class:`Matcher` to apply on the extracted slice.
+        """
+        return _Slice(self.slice, matcher)
+
+
+class _SliceFactory:
+    """A Higher Order Matcher checking that the sliced values match given matchers.
+    The matcher is applied to the slice extracted from the passed :class:`Sequence`.
+
+    Usage:
+      >>> from pychoir import Slice, And, IsInstance
+      >>> (1, 2, 3) == Slice[1:3]((2, 3))
+      True
+      >>> (1, 2, 3) == Slice[2](And(IsInstance(int), 3))
+      True
+    """
+    def __getitem__(self, slice_: Union[int, slice]) -> _SliceTransformer:
+        """
+        :param slice_: The :class:`slice` to slice from the matched object.
+        """
+        return _SliceTransformer(slice_)
+
+
+Slice = _SliceFactory()
